Skip to contents

Return the base URL for the API

Usage

base_url()

Value

A string containing the base URL.

Deprecated

base_url() is a low level building block that was never meant to be part of the public interface. It is deprecated as of textrar 0.9.0 and will be removed in a future release. If you rely on it, please open an issue at https://github.com/matutosi/textrar/issues.

Examples

if (FALSE) { # \dontrun{
base_url()
} # }